#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="plugsy/core"
}

do_install_detail() {
  local config=`uci get plugsy.@plugsy[0].config_path 2>/dev/null`
  local port=`uci get plugsy.@plugsy[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get plugsy.@plugsy[0].image_name 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=3030
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=plugsy/core

  
  # Create Docker Compose file with custom variables
   
  # Create Docker Compose file with custom variables
touch docker-compose.yml
cat > docker-compose.yml <<EOF
version: "2.1"
services:
  plugsy:
    image: ${IMAGE_NAME}
    container_name: plugsy
    volumes:
      - /var/run/docker.sock:/var/run/docker.sock
    ports:
      - ${port}:3000
    restart: unless-stopped

  vikunjadb:
    image: mariadb:10
    container_name: vikunjadb
    command: --character-set-server=utf8mb4 --collation-server=utf8mb4_unicode_ci
    restart: unless-stopped

  vikunjaapi:
    container_name: vikunjaapi
    image: vikunja/api
    restart: unless-stopped

  vikunjafrontend:
    image: vikunja/frontend
    container_name: vikunjafrontend
    restart: unless-stopped

EOF
  
  docker-compose up -d
 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install the Ghost blog"
  echo "      upgrade                Upgrade the Ghost blog"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart the Ghost blog"
  echo "      status                 Ghost blog status"
  echo "      port                   Ghost blog port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker rm -f ghost
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} ghost
  ;;
  "status")
    docker ps --all -f 'name=ghost' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=ghost' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
